@@ -4,7 +4,7 @@
 #' Create a hidden \code{.netrc} file with Earthdata login credentials in your 
 #' home directory. The information included therein is used to login to 
 #' \url{urs.earthdata.nasa.gov} which is a mandatory requirement in order to 
-#' download MODIS data from LPDAAC, LAADS and NSIDC (see also 
+#' download MODIS data from LP DAAC and NSIDC (see also 
 #' \code{\link{MODISoptions}}). If \code{.netrc} does exists the function can
 #' be used to re-enter credentials.  
 #' 
@@ -47,7 +47,8 @@ EarthdataLogin <- function(usr = NULL, pwd = NULL) {
   # create file
   if(!file.exists(nrc))
   {
-    cat("Creating clear text file '",nrc,"' with Earthdata login credentials for 'LPDAAC', 'LAADS' and 'NSIDC'...\n",sep="")
+    cat("Creating clear text file '~/", basename(nrc)
+        , "' with Earthdata login credentials for LP DAAC and NSIDC...\n", sep = "")
     insert <- 'y'
   } else
   {
@@ -131,7 +132,7 @@ readCredentials = function() {
   nrc = path.expand("~/.netrc")
   
   # if (!file.exists(nrc)) {
-  #   stop("~/.netrc file required. Either run lpdaacLogin() or set"
+  #   stop("~/.netrc file required. Either run EarthdataLogin() or set"
   #        , " MODISoptions(MODISserverOrder = 'LAADS').")
     
   if (file.exists(nrc))
