@@ -7,7 +7,7 @@
 #' @slot tile MODIS tile ID as \code{character}.
 #' @slot tileH MODIS horizontal tile ID as \code{integer}.
 #' @slot tileV MODIS vertical tile ID as \code{integer}.
-#' @slot extent Extent information, see \code{\link{getTile}}.
+#' @slot extent \code{Extent} information, see \code{\link{getTile}}.
 #' @slot system Sensor system as \code{character}.
 #' @slot target If applicable, a \code{list} with additional target information.
 #' 
@@ -21,7 +21,7 @@ setClass('MODISextent',
          slots = c(tile = 'character',
                    tileH = 'integer',
                    tileV = 'integer',
-                   extent = 'ANY',
+                   extent = 'Extent',
                    system = 'character',
                    target = 'listORnull')
          )
