@@ -43,9 +43,10 @@
 #' @examples 
 #' \dontrun{
 #' 
-#' # example MOD13Q1 see https://lpdaac.usgs.gov/products/modis_products_table/mod13q1 
+#' # example MOD13Q1 see MODIS Vegetation Index User's Guide (MOD13 Series; 
+#' # https://lpdaac.usgs.gov/sites/default/files/public/product_documentation/mod13_user_guide.pdf)
 #' # enter in Layers
-#' # See in TABLE 2: MOD13Q1 VI Quality
+#' # See in TABLE 5: Descriptions of the VI Quality Assessment Science Data Sets (QA SDS).
 #' # column 1 (bit) row 2 VI usefulness 
 #' bitShift = 2
 #' bitMask = 15 # ('15' is the decimal of the binary '1111')  
@@ -147,16 +148,17 @@ extractBits <- function(x, bitShift=2, bitMask=15, filename='',...)
         tr  <- blockSize(out)
     
         for (i in 1:tr$n) 
-        {
+        { # i=1
             v  <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
             ve <- dim(v)
-
-            v[v==0] <- NA    
+            
+            #v[v==0] <- NA    
             
             # decode bits
             v <- bitAnd(bitShiftR(v, bitShift ), bitMask)
             
-            v[is.na(v)] <- bitMask
+            # set to 
+            #v[is.na(v)] <- bitMask
                         
             if (!is.null(ve))
             {
@@ -171,12 +173,12 @@ extractBits <- function(x, bitShift=2, bitMask=15, filename='',...)
     {
         ve <- dim(x)
         
-        x[x==0] <- NA
+        #x[x==0] <- NA
 
         # decode bits
         x <- bitAnd(bitShiftR(x, bitShift ), bitMask)
 
-        x[is.na(x)] <- bitMask        
+        #x[is.na(x)] <- bitMask        
 
         if (!is.null(ve))
         {
@@ -207,12 +209,12 @@ makeWeights <- function(x, bitShift=2, bitMask=15, threshold=NULL, filename='',
             v  <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
             ve <- dim(v)
 
-            v[v==0] <- NA    
+            #v[v==0] <- NA    
             
             # decode bits
             v <- bitAnd(bitShiftR(v, bitShift ), bitMask)
             
-            v[is.na(v)] <- bitMask
+            #v[is.na(v)] <- bitMask
                     
             if (!is.null(threshold))
             {
@@ -240,12 +242,12 @@ makeWeights <- function(x, bitShift=2, bitMask=15, threshold=NULL, filename='',
     {
         ve <- dim(x)
         
-        x[x==0] <- NA
+        #x[x==0] <- NA
 
         # decode bits
         x <- bitAnd(bitShiftR(x, bitShift ), bitMask)
 
-        x[is.na(x)] <- bitMask        
+        #x[is.na(x)] <- bitMask        
 
         if (!is.null(threshold))
         {
