@@ -5,13 +5,13 @@ options("warn" = 0)
 on.exit(options("warn" = opt))
 
 test_that("product selection wo/pattern matching skips derivatives", {
-  out1 = expect_warning(skipDuplicateProducts("MOD17A2"))
-  expect_match(out1, "\\^MOD17A2\\$")
+  out1 = expect_warning(skipDuplicateProducts("MOD14"))
+  expect_match(out1, "\\^MOD14\\$")
 })
 
 test_that("product selection w/pattern matching includes derivatives", {
-  out2 = skipDuplicateProducts("MOD17A2*")
-  expect_match(out2, "MOD17A2\\*")
+  out2 = skipDuplicateProducts("MOD14.*")
+  expect_match(out2, "MOD14\\.\\*")
   
   lns = capture.output(getProduct(out2))
   expect_equal(length(lns), length(grep(out2, MODIS_Products$PRODUCT)))
